Your message dated Wed, 20 Aug 2014 12:49:32 +0000
with message-id <e1xk5kw-0000bp...@franck.debian.org>
and subject line Bug#754359: fixed in trousers 0.3.13-2
has caused the Debian Bug report #754359,
regarding trousers: FTBFS on hurd-i386 and kfreebsd-any
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact ow...@bugs.debian.org
immediately.)


-- 
754359: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=754359
Debian Bug Tracking System
Contact ow...@bugs.debian.org with problems
--- Begin Message ---
Source: trousers
Version: 0.3.13-1
Severity: important
Tags: patch
User: debian-h...@lists.debian.org
Usertags: hurd, kfreebsd

Hi,

trousers fails to build from source for GNU/Hurd and GNU/kFreeBSD due
to usage of HOST_NAME_MAX, which is not defined on these architectures.
The attached patch fixes this by using _POSIX_HOST_NAME_MAX instead
which is defined, including GNU/Linux. Alternately sysconf(3) could
have been used but a simple test program reveals that -1 is returned on
both Hurd and kFreeBSD.

Thanks!

Index: trousers-0.3.13/src/tspi/tsp_tcsi_param.c
===================================================================
--- trousers-0.3.13.orig/src/tspi/tsp_tcsi_param.c
+++ trousers-0.3.13/src/tspi/tsp_tcsi_param.c
@@ -11,7 +11,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
-#include <bits/local_lim.h>
+#include <bits/posix1_lim.h>
 #include "trousers/tss.h"
 #include "trousers/trousers.h"
 #include "trousers_types.h"
@@ -85,7 +85,7 @@ get_tcsd_port(char port_str[TCP_PORT_STR
 }
 
 /**
  *  Allocates a string with up to HOST_NAME_MAX chars which contains
  *  the hostname extracted from the env var
  */
 int
@@ -109,8 +109,8 @@ get_hostname_from_env(char **host_str, u
 
 	LogDebug("Environment var %s got value: %s", HOSTNAME_ENV_VAR, tmp_str);
 	env_len = strlen(tmp_str);
-	if (env_len > HOST_NAME_MAX) {
-		*len = HOST_NAME_MAX + 1;
+	if (env_len > _POSIX_HOST_NAME_MAX) {
+		*len = _POSIX_HOST_NAME_MAX + 1;
 	} else {
 		*len = env_len + 1;
 	}

--- End Message ---
--- Begin Message ---
Source: trousers
Source-Version: 0.3.13-2

We believe that the bug you reported is fixed in the latest version of
trousers, which is due to be installed in the Debian FTP archive.

A summary of the changes between this version and the previous one is
attached.

Thank you for reporting the bug, which will now be closed.  If you
have further comments please address them to 754...@bugs.debian.org,
and the maintainer will reopen the bug report if appropriate.

Debian distribution maintenance software
pp.
Pierre Chifflier <pol...@debian.org> (supplier of updated trousers package)

(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing ftpmas...@ftp-master.debian.org)


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Format: 1.8
Date: Wed, 20 Aug 2014 14:27:23 +0200
Source: trousers
Binary: trousers trousers-dbg libtspi1 libtspi-dev
Architecture: source amd64
Version: 0.3.13-2
Distribution: unstable
Urgency: medium
Maintainer: Pierre Chifflier <pol...@debian.org>
Changed-By: Pierre Chifflier <pol...@debian.org>
Description:
 libtspi-dev - open-source TCG Software Stack (development)
 libtspi1   - open-source TCG Software Stack (library)
 trousers   - open-source TCG Software Stack (daemon)
 trousers-dbg - open-source TCG Software Stack (debug)
Closes: 754359
Changes:
 trousers (0.3.13-2) unstable; urgency=medium
 .
   * Fix FTBFS on hurd-i386 and kfreebsd-any (Closes: #754359)
     Thanks to Svante Signell for the patch.
Checksums-Sha1:
 57c429bf81ad1294774af6d6a421f1918dbfd3aa 1595 trousers_0.3.13-2.dsc
 7801bb80ec08737c57130317e4aa05fa433d965a 15452 trousers_0.3.13-2.debian.tar.xz
 e30a94758acc462f34debef5ec84ea3a68cf2768 138660 trousers_0.3.13-2_amd64.deb
 b8baf6164da3410ae9443e7982135d46106a2f50 841974 trousers-dbg_0.3.13-2_amd64.deb
 dac849f47bc9216664e823d6051a05e8bf0a05d6 167956 libtspi1_0.3.13-2_amd64.deb
 e4b21e635328b11e958a86cbd33f0dc46806866b 634716 libtspi-dev_0.3.13-2_amd64.deb
Checksums-Sha256:
 aed76691917f1127392cd7d4d0dbc3bdc616ea385d598b74420d02b825f70438 1595 
trousers_0.3.13-2.dsc
 a12fb7bde96f566acd8d41e425b71aae8629808a42a01ae71743a90fe857ef62 15452 
trousers_0.3.13-2.debian.tar.xz
 0d87abaf1d89c919917dbbef4fcbd1cdfbbc385a8c6e1dc5e9c6b0a40e0fbfd9 138660 
trousers_0.3.13-2_amd64.deb
 1ee8f5be8d0e86195e72aca540cc81402b9fd6e58eab5279b66326a2cf9da259 841974 
trousers-dbg_0.3.13-2_amd64.deb
 fef9b980579630f7a48170d6f7fe5015cfbfa4b812849136a76312cd0d758995 167956 
libtspi1_0.3.13-2_amd64.deb
 1b6a766c1858aed95cd8bd352c0ba14d8f092945c0efc3ec2eba649ccbbf4642 634716 
libtspi-dev_0.3.13-2_amd64.deb
Files:
 0579d1c37c42a182d9ba0537c358ab5e 138660 admin optional 
trousers_0.3.13-2_amd64.deb
 0a0537e0c5214b40bab31addc83146a4 841974 debug extra 
trousers-dbg_0.3.13-2_amd64.deb
 ce293efa2b72a7e3c830d239678f8390 167956 libs optional 
libtspi1_0.3.13-2_amd64.deb
 02d3856508c1c922acc0cba206a0201e 634716 libdevel optional 
libtspi-dev_0.3.13-2_amd64.deb
 023c18a2973c8a59b3292036e573647a 1595 admin optional trousers_0.3.13-2.dsc
 61cbeccc7892ba640e07602ae2a2e750 15452 admin optional 
trousers_0.3.13-2.debian.tar.xz

-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1

iQEcBAEBAgAGBQJT9JToAAoJEFqCeQfe0MQYiNYH+QGiMEA0+8NuAMrjTSZmU1MI
ndSIoY8Wg33jpHVOGXxySCiSUG/R73sH9Craw6qcq4q8788rGZZsDHtx9yqV2F4w
0Ao/pC/EwTvc3MFNxdoQBdBJXGIx45F1QO99V0asf3djl5vtZuCHKWFitvVVYmg3
JNkvDNaxgyOXtK6dRGsrlxYbImmuSUiBy1VU6mTkzm74GLCXHfEtnNEHHKknJZE5
ZAHk6qyvWcHIC+VQ3LpsBo1KoLCgfw8hYgYEgU8qj/NhnF1akx/SBL0co7NmjHXd
zzCzK8r8KaKGecKSkxLywIZoeJX0pWxtORRV4UX0pjMYW+UQ7iyYGAHKwpMn4eI=
=ThZY
-----END PGP SIGNATURE-----

--- End Message ---
@@ -85,7 +85,7 @@ get_tcsd_port(char port_str[TCP_PORT_STR
 
 /**
- *  Allocates a string with up to HOST_NAME_MAX chars which contains
+ *  Allocates a string with up to _POSIX_HOST_NAME_MAX chars which contains
  *  the hostname extracted from the env var
  */

Reply via email to